/* libiso8601/src/libiso8601/functions.h
 *
 *  (c)2006, Laurence Withers, <l@lwithers.me.uk>.
 *  Released under the GNU GPLv2. See file COPYING or
 *  http://www.gnu.org/copyleft/gpl.html for details.
*/



/*! \defgroup parse Parsing and validation routines.

These routines are used for parsing an ISO8601 date/time string into the internal structure used
to represent them, and for validating such dates/times.

*/
/*!@{*/

/*! \brief Parse ISO8601 date/time.

\param str The input string.
\param[out] earliest ...
\param[out] latest The latest possible time the string could represent. May be 0.
\param[out] details Stores details such as the precision to which the time/date were specified. May
    be 0.
\retval -1 on error (and see \a errno).
\retval 0 on success.

Parses a string containing the ISO8601 date/time. Deals with any format of date, optionally storing
the details in \a details. The time may be partial, in which case this function returns the earliest
and latest times that could possibly be represented by the string.

Note that this function will accept leap seconds (23:59:60) on days on which they occurred. It will
also accept the 24:00:00 representation of midnight (end of day).

\todo Strip whitespace.

*/
int iso8601_parse(const char* str, struct iso8601_date* earliest, struct iso8601_date* latest,
    struct iso8601_details* details);

int iso8601_valid(const struct iso8601_date* date);

/*!@}*/



/* c_library.c */
void iso8601_now(struct iso8601_date* date, struct iso8601_details* details);
void iso8601_from_ts(struct iso8601_date* date, const struct timespec* ts);
void iso8601_to_ts(struct timespec* ts, const struct iso8601_date* date);
void iso8601_from_time_t(struct iso8601_date* date, const time_t* t);
void iso8601_to_time_t(time_t* t, const struct iso8601_date* date);

/* calc.c */
int iso8601_isleap(int year);
void iso8601_to_cal(int* year, int* month, int* day, const struct iso8601_date* date);
int iso8601_from_cal(struct iso8601_date* date, int year, int month, int day);
void iso8601_to_ord(int* year, int* oday, const struct iso8601_date* date);
int iso8601_from_ord(struct iso8601_date* date, int year, int oday);
void iso8601_to_week(int* year, int* week, int* wday, const struct iso8601_date* date);
int iso8601_from_week(struct iso8601_date* date, int year, int week, int wday);
void iso8601_to_clocktime(int* hour, int* min, int* sec, const struct iso8601_date* date);
int iso8601_from_clocktime(struct iso8601_date* date, int hour, int min, int sec);

/* print.c */
void iso8601_print(char* str, int amt, const struct iso8601_date* date, 
    const struct iso8601_details* details);

/* manip.c */
int iso8601_lt(const struct iso8601_date* d1, const struct iso8601_date* d2);
int iso8601_lte(const struct iso8601_date* d1, const struct iso8601_date* d2);
int iso8601_eq(const struct iso8601_date* d1, const struct iso8601_date* d2);
void iso8601_add_seconds(struct iso8601_date* date, long seconds);
void iso8601_add_nanoseconds(struct iso8601_date* date, long nano);

/* leap.c */
int iso8601_seconds_leap(const struct iso8601_date* date);
int iso8601_valid_leap(const struct iso8601_date* date);
int iso8601_leap_elapsed(const struct iso8601_date* start, const struct iso8601_date* end);

/* options for text editors
kate: replace-trailing-space-save true; space-indent true; tab-width 4;
vim: expandtab:ts=4:sw=4
*/
